@@ -4,12 +4,12 @@
     mslib.msui._tests.test_mscolab_admin_window
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    This module is used to test mscolab-project related gui.
+    This module is used to test mscolab-operation related gui.
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: Copyright 2019 Shivashis Padhi
-    :copyright: Copyright 2019-2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2019-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,40 +27,65 @@
 import os
 import pytest
 import sys
-import time
 
-from mslib.msui.mscolab import MSSMscolabWindow
 from mslib.mscolab.conf import mscolab_settings
 from PyQt5 import QtCore, QtTest, QtWidgets
 from mslib._tests.utils import mscolab_start_server
+from mslib.msui import mscolab
+from mslib.msui import msui
+from mslib.mscolab.mscolab import handle_db_reset
+from mslib.mscolab.seed import add_user, get_user, add_operation, add_user_to_operation
 
 
-PORTS = list(range(9531, 9550))
+PORTS = list(range(24000, 24500))
 
 
 @pytest.mark.skipif(os.name == "nt",
                     reason="multiprocessing needs currently start_method fork")
 class Test_MscolabAdminWindow(object):
     def setup(self):
+        handle_db_reset()
         self.process, self.url, self.app, _, self.cm, self.fm = mscolab_start_server(PORTS)
-        time.sleep(0.1)
+        self.userdata = 'UV10@uv10', 'UV10', 'uv10'
+        self.operation_name = "europe"
+        assert add_user(self.userdata[0], self.userdata[1], self.userdata[2])
+        assert add_operation(self.operation_name, "test europe")
+        assert add_user_to_operation(path=self.operation_name, emailid=self.userdata[0])
+        self.user = get_user(self.userdata[0])
+        assert add_user("collaborator@example.de", "example", "example")
+        assert add_user_to_operation(path=self.operation_name,
+                                     emailid="collaborator@example.de", access_level="collaborator")
+        assert add_user("viewer@example.de", "viewer", "viewer")
+        assert add_user_to_operation(path=self.operation_name, emailid="viewer@example.de", access_level="viewer")
+        assert add_user("name1@example.de", "name1", "name1")
+        assert add_user("name2@example.de", "name2", "name2")
+        assert add_operation("paris", "test paris")
+        assert add_user_to_operation(path="paris", emailid=self.userdata[0])
+        assert add_user_to_operation(path="paris", emailid="name1@example.de")
+        assert add_operation("tokyo", "test tokyo")
+        assert add_user_to_operation(path="tokyo", emailid=self.userdata[0])
+
+        QtTest.QTest.qWait(500)
         self.application = QtWidgets.QApplication(sys.argv)
-        self.window = MSSMscolabWindow(data_dir=mscolab_settings.MSCOLAB_DATA_DIR,
-                                       mscolab_server_url=self.url)
+        self.window = msui.MSUIMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
+        self.window.show()
+        # connect and login to mscolab
         self._connect_to_mscolab()
-        self._login()
-        self._activate_project_at_index(0)
-        QtTest.QTest.mouseClick(self.window.adminWindowBtn, QtCore.Qt.LeftButton)
+        self._login(emailid=self.userdata[0], password=self.userdata[2])
+        # activate operation and open chat window
+        self._activate_operation_at_index(0)
+        self.window.actionManageUsers.trigger()
         QtWidgets.QApplication.processEvents()
-        self.admin_window = self.window.admin_window
+        self.admin_window = self.window.mscolab.admin_window
         QtTest.QTest.qWaitForWindowExposed(self.window)
         QtWidgets.QApplication.processEvents()
 
     def teardown(self):
-        if self.window.admin_window:
-            self.window.admin_window.close()
-        if self.window.conn:
-            self.window.conn.disconnect()
+        self.window.mscolab.logout()
+        if self.window.mscolab.admin_window:
+            self.window.mscolab.admin_window.close()
+        if self.window.mscolab.conn:
+            self.window.mscolab.conn.disconnect()
         self.application.quit()
         QtWidgets.QApplication.processEvents()
         self.process.terminate()
@@ -84,7 +109,7 @@ class Test_MscolabAdminWindow(object):
         len_unadded_users = self.admin_window.addUsersTable.rowCount()
         len_added_users = self.admin_window.modifyUsersTable.rowCount()
         # Text Search in add users Table
-        QtTest.QTest.keyClicks(self.admin_window.addUsersSearch, "test2")
+        QtTest.QTest.keyClicks(self.admin_window.addUsersSearch, "name1")
         QtWidgets.QApplication.processEvents()
         visible_row_count = self._get_visible_row_count(self.admin_window.addUsersTable)
         assert visible_row_count == 1
@@ -94,7 +119,7 @@ class Test_MscolabAdminWindow(object):
         visible_row_count = self._get_visible_row_count(self.admin_window.addUsersTable)
         assert visible_row_count == len_unadded_users
         # Text Search in modify users Table
-        QtTest.QTest.keyClicks(self.admin_window.modifyUsersSearch, "test4")
+        QtTest.QTest.keyClicks(self.admin_window.modifyUsersSearch, "example")
         QtWidgets.QApplication.processEvents()
         visible_row_count = self._get_visible_row_count(self.admin_window.modifyUsersTable)
         assert visible_row_count == 1
@@ -105,7 +130,7 @@ class Test_MscolabAdminWindow(object):
         assert visible_row_count == len_added_users
 
     def test_permission_and_text_together(self):
-        QtTest.QTest.keyClicks(self.admin_window.modifyUsersSearch, "test4")
+        QtTest.QTest.keyClicks(self.admin_window.modifyUsersSearch, "viewer")
         self.admin_window.modifyUsersPermissionFilter.currentTextChanged.emit("viewer")
         QtWidgets.QApplication.processEvents()
         visible_row_count = self._get_visible_row_count(self.admin_window.modifyUsersTable)
@@ -118,9 +143,12 @@ class Test_MscolabAdminWindow(object):
     def test_add_permissions(self):
         len_unadded_users = self.admin_window.addUsersTable.rowCount()
         len_added_users = self.admin_window.modifyUsersTable.rowCount()
-        users = ["test2", "test3"]
+        users = ["name1", "name2"]
         # Select users in the add users table
         self._select_users(self.admin_window.addUsersTable, users)
+        index = self.admin_window.addUsersPermission.findText("admin", QtCore.Qt.MatchFixedString)
+        if index >= 0:
+            self.admin_window.addUsersPermission.setCurrentIndex(index)
         QtTest.QTest.mouseClick(self.admin_window.addUsersBtn, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
         # Check if they have been added in the modify users table
@@ -129,10 +157,7 @@ class Test_MscolabAdminWindow(object):
         assert len_added_users + 2 == self.admin_window.modifyUsersTable.rowCount()
 
     def test_modify_permissions(self):
-        self._connect_to_mscolab()
-        self._login()
-        self._activate_project_at_index(0)
-        users = ["test2", "test3"]
+        users = ["name1", "name2"]
         # Select users in the add users table
         self._select_users(self.admin_window.addUsersTable, users)
         QtTest.QTest.mouseClick(self.admin_window.addUsersBtn, QtCore.Qt.LeftButton)
@@ -148,11 +173,8 @@ class Test_MscolabAdminWindow(object):
         self._check_users_present(self.admin_window.modifyUsersTable, users, "viewer")
 
     def test_delete_permissions(self):
-        self._connect_to_mscolab()
-        self._login()
-        self._activate_project_at_index(0)
         # Select users in the add users table
-        users = ["test2", "test3"]
+        users = ["name1", "name2"]
         self._select_users(self.admin_window.addUsersTable, users)
         QtTest.QTest.mouseClick(self.admin_window.addUsersBtn, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
@@ -170,34 +192,35 @@ class Test_MscolabAdminWindow(object):
         assert len_added_users - 2 == self.admin_window.modifyUsersTable.rowCount()
 
     def test_import_permissions(self):
-        self._connect_to_mscolab()
-        self._login()
-        self._activate_project_at_index(0)
-        index = self.admin_window.importPermissionsCB.findText("three", QtCore.Qt.MatchFixedString)
+        index = self.admin_window.importPermissionsCB.findText("paris", QtCore.Qt.MatchFixedString)
         self.admin_window.importPermissionsCB.setCurrentIndex(index)
         QtTest.QTest.mouseClick(self.admin_window.importPermissionsBtn, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        time.sleep(0.1)
-        assert self.admin_window.modifyUsersTable.rowCount() == 5
+        QtTest.QTest.qWait(100)
+        assert self.admin_window.modifyUsersTable.rowCount() == 2
 
     def _connect_to_mscolab(self):
-        self.window.url.setEditText(self.url)
-        QtTest.QTest.mouseClick(self.window.toggleConnectionBtn, QtCore.Qt.LeftButton)
-        time.sleep(0.1)
-
-    def _login(self):
-        # login
-        self.window.emailid.setText('test1')
-        self.window.password.setText('test1')
-        QtTest.QTest.mouseClick(self.window.loginButton, QtCore.Qt.LeftButton)
+        self.connect_window = mscolab.MSColab_ConnectDialog(parent=self.window, mscolab=self.window.mscolab)
+        self.window.mscolab.connect_window = self.connect_window
+        self.connect_window.urlCb.setEditText(self.url)
+        self.connect_window.show()
+        QtTest.QTest.mouseClick(self.connect_window.connectBtn, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
+        QtTest.QTest.qWait(500)
 
-    def _activate_project_at_index(self, index):
-        item = self.window.listProjects.item(index)
-        point = self.window.listProjects.visualItemRect(item).center()
-        QtTest.QTest.mouseClick(self.window.listProjects.viewport(), QtCore.Qt.LeftButton, pos=point)
+    def _login(self, emailid, password):
+        self.connect_window.loginEmailLe.setText(emailid)
+        self.connect_window.loginPasswordLe.setText(password)
+        QtTest.QTest.mouseClick(self.connect_window.loginBtn, QtCore.Qt.LeftButton)
         QtWidgets.QApplication.processEvents()
-        QtTest.QTest.mouseDClick(self.window.listProjects.viewport(), QtCore.Qt.LeftButton, pos=point)
+        QtTest.QTest.qWait(500)
+
+    def _activate_operation_at_index(self, index):
+        item = self.window.listOperationsMSC.item(index)
+        point = self.window.listOperationsMSC.visualItemRect(item).center()
+        QtTest.QTest.mouseClick(self.window.listOperationsMSC.viewport(), QtCore.Qt.LeftButton, pos=point)
+        QtWidgets.QApplication.processEvents()
+        QtTest.QTest.mouseDClick(self.window.listOperationsMSC.viewport(), QtCore.Qt.LeftButton, pos=point)
         QtWidgets.QApplication.processEvents()
 
     def _select_users(self, table, users):
