@@ -6,10 +6,10 @@
 
     This module is used to test mscolab-operation related gui.
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: Copyright 2020 Tanish Grover
-    :copyright: Copyright 2020-2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2020-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -33,7 +33,7 @@ from mslib._tests.utils import mscolab_start_server
 from mslib.mscolab.conf import mscolab_settings
 from PyQt5 import QtCore, QtTest, QtWidgets
 from mslib.msui import mscolab
-import mslib.msui.mss_pyui as mss_pyui
+from mslib.msui import msui
 from mslib.mscolab.mscolab import handle_db_reset
 from mslib.mscolab.seed import add_user, get_user, add_operation, add_user_to_operation
 
@@ -55,7 +55,7 @@ class Test_MscolabVersionHistory(object):
         self.user = get_user(self.userdata[0])
         QtTest.QTest.qWait(500)
         self.application = QtWidgets.QApplication(sys.argv)
-        self.window = mss_pyui.MSSMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
+        self.window = msui.MSUIMainWindow(mscolab_data_dir=mscolab_settings.MSCOLAB_DATA_DIR)
         self.window.show()
         # connect and login to mscolab
         self._connect_to_mscolab()
@@ -70,6 +70,7 @@ class Test_MscolabVersionHistory(object):
         QtWidgets.QApplication.processEvents()
 
     def teardown(self):
+        self.window.mscolab.logout()
         if self.window.mscolab.version_window:
             self.window.mscolab.version_window.close()
         if self.window.mscolab.conn:
