@@ -12,11 +12,11 @@
     plotted map elements to allow the user to toggle their visibility, or
     to redraw when map section (zoom/pan) or projection have been changed.
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -49,7 +49,7 @@ except ImportError:
     import pyproj
 
 from mslib.msui import mpl_pathinteractor as mpl_pi
-from mslib.utils import get_airports, get_airspaces
+from mslib.utils.airdata import get_airports, get_airspaces
 
 
 OPENAIP_NOTICE = "Airspace data used comes from openAIP.\n" \
@@ -63,7 +63,7 @@ class MapCanvas(basemap.Basemap):
     automatically draw a graticule and to redraw specific map elements.
     """
 
-    def __init__(self, identifier=None, CRS=None, BBOX_UNITS=None, PROJECT_NAME=None,
+    def __init__(self, identifier=None, CRS=None, BBOX_UNITS=None, OPERATION_NAME=None,
                  appearance=None, **kwargs):
         """
         New constructor automatically adds coastlines, continents, and
@@ -74,7 +74,7 @@ class MapCanvas(basemap.Basemap):
         Additional arguments:
         CRS -- string describing the coordinate reference system of the map.
         BBOX_UNITS -- string describing the units of the map coordinates.
-        PROJECT_NAME -- string with project name
+        OPERATION_NAME -- string with operation name
 
         """
         # Coordinate reference system identifier and coordinate system units.
@@ -84,8 +84,8 @@ class MapCanvas(basemap.Basemap):
         else:
             self.bbox_units = getattr(self, "bbox_units", None)
 
-        self.project_name = PROJECT_NAME if PROJECT_NAME is not None else self.project_name \
-            if hasattr(self, "project_name") else None
+        self.operation_name = OPERATION_NAME if OPERATION_NAME is not None else self.operation_name \
+            if hasattr(self, "operation_name") else None
 
         # Dictionary containing map appearance settings.
         if appearance is not None:
@@ -114,11 +114,15 @@ class MapCanvas(basemap.Basemap):
         # delete the attribute (mr, 08Feb2013).
         if hasattr(self, "epsg"):
             del self.epsg
-        super(MapCanvas, self).__init__(**kwargs)
+        super().__init__(**kwargs)
+
+        self.gc = pyproj.Geod(a=self.rmajor, b=self.rminor)
+
         self.kwargs = kwargs
 
         # Set up the map appearance.
         if self.appearance["draw_coastlines"]:
+            self.map_coastlines = None
             if len(self.coastsegs) > 0 and len(self.coastsegs[0]) > 0:
                 self.map_coastlines = self.drawcoastlines(zorder=3)
             self.map_countries = self.drawcountries(zorder=3)
@@ -144,8 +148,8 @@ class MapCanvas(basemap.Basemap):
 
         # Print project name and CRS identifier into figure.
         crs_text = ""
-        if self.project_name is not None:
-            crs_text += self.project_name
+        if self.operation_name is not None:
+            crs_text += self.operation_name
         if self.crs is not None:
             if len(crs_text) > 0:
                 crs_text += "\n"
@@ -284,8 +288,8 @@ class MapCanvas(basemap.Basemap):
         spacingValues = [0.05, 0.1, 0.25, 0.5, 1, 2, 5, 10, 20, 30, 40]
         deltaLon = mapLonStop - mapLonStart
         deltaLat = mapLatStop - mapLatStart
-        spacingLon = [i for i in spacingValues if i > (deltaLon / 11.)][0]
-        spacingLat = [i for i in spacingValues if i > (deltaLat / 11.)][0]
+        spacingLon = ([i for i in spacingValues if i > (deltaLon / 11.)] + [60])[0]
+        spacingLat = ([i for i in spacingValues if i > (deltaLat / 11.)] + [60])[0]
 
         #   c) parallels and meridians start at the first value in the
         #      spacingLon/Lat grid that's smaller than the lon/lat of the
@@ -345,7 +349,7 @@ class MapCanvas(basemap.Basemap):
         """
         Sets airports to visible or not visible
         """
-        if (reload or not value) and self.airports:
+        if (reload or not value or len(port_type) == 0) and self.airports:
             if OURAIRPORTS_NOTICE in self.crs_text.get_text():
                 self.crs_text.set_text(self.crs_text.get_text().replace(f"{OURAIRPORTS_NOTICE}\n", ""))
             self.airports.remove()
@@ -353,14 +357,14 @@ class MapCanvas(basemap.Basemap):
             self.airports = None
             self.airtext = None
             self.ax.figure.canvas.mpl_disconnect(self.airports_event)
-        if value:
+        if value and len(port_type) > 0:
             self.draw_airports(port_type)
 
     def set_draw_airspaces(self, value, airspaces=[], range_km=None, reload=True):
         """
         Sets airspaces to visible or not visible
         """
-        if (reload or not value) and self.airspaces:
+        if (reload or not value or len(airspaces) == 0) and self.airspaces:
             if OPENAIP_NOTICE in self.crs_text.get_text():
                 self.crs_text.set_text(self.crs_text.get_text().replace(f"{OPENAIP_NOTICE}\n", ""))
             self.airspaces.remove()
@@ -368,7 +372,7 @@ class MapCanvas(basemap.Basemap):
             self.airspaces = None
             self.airspacetext = None
             self.ax.figure.canvas.mpl_disconnect(self.airspace_event)
-        if value:
+        if value and len(airspaces) > 0:
             country_codes = [airspace.split(" ")[-1] for airspace in airspaces]
             self.draw_airspaces(country_codes, range_km)
 
@@ -379,7 +383,7 @@ class MapCanvas(basemap.Basemap):
         if not self.airspaces:
             airspaces = copy.deepcopy(get_airspaces(countries))
             if not airspaces:
-                logging.error("Tried to draw airspaces without .aip files.")
+                logging.error("Tried to draw airspaces without asp files.")
                 return
 
             for i, airspace in enumerate(airspaces):
@@ -532,11 +536,14 @@ class MapCanvas(basemap.Basemap):
         """
         self.appearance["draw_coastlines"] = visible
         if visible and self.map_coastlines is None and self.map_countries is None:
-            self.map_coastlines = self.drawcoastlines(zorder=3)
+            self.map_coastlines = None
+            if len(self.coastsegs) > 0 and len(self.coastsegs[0]) > 0:
+                self.map_coastlines = self.drawcoastlines(zorder=3)
             self.map_countries = self.drawcountries(zorder=3)
             self.ax.figure.canvas.draw()
-        elif not visible and self.map_coastlines is not None and self.map_countries is not None:
-            self.map_coastlines.remove()
+        elif not visible and (self.map_coastlines is not None or self.map_countries is not None):
+            if self.map_coastlines is not None:
+                self.map_coastlines.remove()
             self.map_countries.remove()
             del self.cntrysegs
             self.map_coastlines = None
@@ -679,23 +686,22 @@ class MapCanvas(basemap.Basemap):
         self.ax.figure.canvas.draw()
         return self.image
 
-    def gcpoints2(self, lon1, lat1, lon2, lat2, del_s=100., map_coords=True):
+    def gcpoints2(self, lon0, lat0, lon1, lat1, del_s=100., map_coords=True):
         """
         The same as basemap.gcpoints(), but takes a distance interval del_s
         to space the points instead of a number of points.
         """
         # use great circle formula for a perfect sphere.
-        gc = pyproj.Geod(a=self.rmajor, b=self.rminor)
-        az12, az21, dist = gc.inv(lon1, lat1, lon2, lat2)
+        _, _, dist = self.gc.inv(lon0, lat0, lon1, lat1)
         npoints = int((dist + 0.5 * 1000. * del_s) / (1000. * del_s))
-        lonlats = gc.npts(lon1, lat1, lon2, lat2, npoints)
-        lons = [lon1]
-        lats = [lat1]
+        lonlats = self.gc.npts(lon0, lat0, lon1, lat1, npoints)
+        lons = [lon0]
+        lats = [lat0]
         for lon, lat in lonlats:
             lons.append(lon)
             lats.append(lat)
-        lons.append(lon2)
-        lats.append(lat2)
+        lons.append(lon1)
+        lats.append(lat1)
         if map_coords:
             x, y = self(lons, lats)
         else:
@@ -708,50 +714,28 @@ class MapCanvas(basemap.Basemap):
         line segments. lons and lats are lists of waypoint coordinates.
         """
         # use great circle formula for a perfect sphere.
-        gc = pyproj.Geod(a=self.rmajor, b=self.rminor)
         assert len(lons) == len(lats)
         assert len(lons) > 1
         gclons = [lons[0]]
         gclats = [lats[0]]
         for i in range(len(lons) - 1):
-            az12, az21, dist = gc.inv(lons[i], lats[i], lons[i + 1], lats[i + 1])
+            _, _, dist = self.gc.inv(lons[i], lats[i], lons[i + 1], lats[i + 1])
             npoints = int((dist + 0.5 * 1000. * del_s) / (1000. * del_s))
-            # BUG -- weird path in cyl projection on waypoint move
-            # On some system configurations, the path is wrongly plotted when one
-            # of the waypoints is moved by the user and the current projection is cylindric.
-            # The weird thing is that when comparing cyl projection and stereo projection
-            # (which works), the exact same arguments are passed to gc.npts(). Also, the
-            # gc is initialised with the exact same a and b. Nevertheless, for the cyl
-            # projection, gc.npts() returns lons that connect lon1 and lat2, not lon1 and
-            # lon2 ... I cannot figure out why, maybe this is an issue in certain versions
-            # of pyproj?? (mr, 16Oct2012)
             lonlats = []
             if npoints > 0:
-                lonlats = gc.npts(lons[i], lats[i], lons[i + 1], lats[i + 1], npoints)
-            # The cylindrical projection of matplotlib is not periodic, that means that
-            # -170 longitude and 190 longitude are not identical. The gc projection however
-            # assumes identity and maps all longitudes to -180 to 180. This is no issue for
-            # most other projections.
-            # The clean solution would be to have a periodic display, where the locations
-            # and path are plotted periodically every 360 degree. As long as this is not
-            # supported by matplotlib.basemap, we "hack" this to map the path to the
-            # longitude range defined by the locations. This breaks potentially down in case
-            # that the locations are too far apart (>180 degree), but this is not the typical
-            # use case and will thus hopefully not pose a problem.
-            if self.projection == "cyl" and npoints > 0:
-                lonlats = np.asarray(lonlats)
-                milon = min(lons[i], lons[i + 1])
-                malon = max(lons[i], lons[i + 1])
-                sel = lonlats[:, 0] < milon
-                lonlats[sel, 0] += 360
-                sel = lonlats[:, 0] > malon
-                lonlats[sel, 0] -= 360
-
+                lonlats = self.gc.npts(lons[i], lats[i], lons[i + 1], lats[i + 1], npoints)
             for lon, lat in lonlats:
                 gclons.append(lon)
                 gclats.append(lat)
             gclons.append(lons[i + 1])
             gclats.append(lats[i + 1])
+        if self.projection == "cyl":  # hack for wraparound
+            lon_min, lon_max = self.llcrnrlon, self.urcrnrlon
+            gclons = np.array(gclons)
+            gclons[gclons < lon_min] += 360
+            gclons[gclons > lon_max] -= 360
+            idcs = np.where(abs(np.diff(gclons)) > 300)[0]
+            gclons[idcs] = np.nan
         if map_coords:
             x, y = self(gclons, gclats)
         else:
