@@ -6,10 +6,10 @@
     Improves upon the old method of loading each layer on UI changes,
     the layers are all persistent and fully functional without requiring user input.
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: Copyright 2021 May Bär
-    :copyright: Copyright 2021 by the mss team, see AUTHORS.
+    :copyright: Copyright 2021-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -28,8 +28,8 @@ from PyQt5 import QtWidgets, QtCore, QtGui
 import logging
 import mslib.msui.wms_control
 from mslib.msui.icons import icons
-from mslib.msui.mss_qt import ui_wms_multilayers as ui
-from mslib.utils import save_settings_qsettings, load_settings_qsettings
+from mslib.utils.qt import ui_wms_multilayers as ui
+from mslib.utils.config import save_settings_qsettings, load_settings_qsettings
 
 
 class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
@@ -62,9 +62,10 @@ class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
         self.settings = load_settings_qsettings("multilayers",
                                                 {"favourites": [], "saved_styles": {}, "saved_colors": {}})
         self.synced_reference = Layer(None, None, None, is_empty=True)
+        self.skip_clicked_event = False
         self.listLayers.itemChanged.connect(self.multilayer_changed)
-        self.listLayers.itemClicked.connect(self.multilayer_clicked)
         self.listLayers.itemClicked.connect(self.check_icon_clicked)
+        self.listLayers.itemClicked.connect(self.multilayer_clicked)
         self.listLayers.itemDoubleClicked.connect(self.multilayer_doubleclicked)
         self.listLayers.setVisible(True)
 
@@ -142,6 +143,7 @@ class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
                 icon_start += checkbox_width + 6
             position = self.listLayers.viewport().mapFromGlobal(QtGui.QCursor().pos())
             if icon_start <= position.x() <= icon_start + icon_width:
+                self.skip_clicked_event = True
                 self.threads += 1
                 item.favourite_triggered()
                 if self.filter_favourite:
@@ -175,30 +177,36 @@ class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
         """
         Updates the self.synced_reference layer to contain the common options of all synced layers
         """
-        levels, itimes, vtimes, crs = self.get_multilayer_common_options()
-        self.synced_reference.levels = levels
-        self.synced_reference.itimes = itimes
-        self.synced_reference.vtimes = vtimes
-        self.synced_reference.allowed_crs = crs
+        sr = self.synced_reference
+        sr.levels, sr.itimes, sr.vtimes, sr.allowed_crs = self.get_multilayer_common_options()
 
         if self.current_layer:
-            if not self.synced_reference.level:
-                self.synced_reference.level = self.current_layer.level
-            if not self.synced_reference.itime:
-                self.synced_reference.itime = self.current_layer.itime
-            if not self.synced_reference.vtime:
-                self.synced_reference.vtime = self.current_layer.vtime
+            if not sr.level:
+                sr.level = self.current_layer.level
+            if not sr.itime:
+                sr.itime = self.current_layer.itime
+            if not sr.vtime:
+                sr.vtime = self.current_layer.vtime
 
-        if self.synced_reference.level not in self.synced_reference.levels:
-            self.synced_reference.level = levels[0] if levels else None
+        if sr.level not in sr.levels:
+            sr.level = None
+            if sr.levels:
+                sr.level = sr.levels[0]
 
-        if self.synced_reference.itime not in self.synced_reference.itimes:
-            self.synced_reference.itime = itimes[-1] if itimes else None
+        if sr.itime not in sr.itimes:
+            sr.itime = None
+            if sr.itimes:
+                sr.itime = sr.itimes[-1]
 
-        if self.synced_reference.vtime not in self.synced_reference.vtimes or \
-                self.synced_reference.vtime < self.synced_reference.itime:
-            self.synced_reference.vtime = next((vtime for vtime in vtimes if
-                                                vtime >= self.synced_reference.itime), None) if vtimes else None
+        if sr.itime is not None:
+            if sr.vtime not in sr.vtimes or sr.vtime < sr.itime:
+                sr.vtime = None
+                if sr.vtimes:
+                    sr.vtime = next((vtime for vtime in sr.vtimes if vtime >= sr.itime), None)
+        elif sr.vtime not in sr.vtimes:
+            sr.vtime = None
+            if sr.vtimes:
+                sr.vtime = sr.vtimes[0]
 
     def filter_multilayers(self, filter_string=None):
         """
@@ -281,6 +289,15 @@ class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
                     active_layers.append(widget)
         return sorted(active_layers, key=lambda layer: self.get_multilayer_priority(layer))
 
+    def get_plot_title(self):
+        """
+        Returns the plot title
+        """
+        title = self.get_current_layer().layerobj.title
+        if len(self.get_active_layers()) > 1 and self.get_current_layer().checkState(0):
+            title = f"{title} (and {len(self.get_active_layers()) - 1} more)"
+        return title
+
     def update_priority_selection(self):
         """
         Updates the priority numbers for the selected layers to the sorted self.layers_priority list
@@ -315,7 +332,7 @@ class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
             icon = QtGui.QIcon(icons("64x64", "bin.png"))
             header.setIcon(0, icon)
 
-    def add_multilayer(self, name, wms):
+    def add_multilayer(self, name, wms, auto_select=False):
         """
         Adds a layer to the multilayer list, with the wms url as a parent
         """
@@ -369,14 +386,20 @@ class Multilayers(QtWidgets.QDialog, ui.Ui_MultilayersDialog):
             if widget.is_invalid:
                 widget.setDisabled(True)
                 return
-            self.current_layer = widget
-            self.listLayers.setCurrentItem(widget)
+
+            if not self.current_layer or auto_select:
+                self.current_layer = widget
+                self.listLayers.setCurrentItem(widget)
 
     def multilayer_clicked(self, item):
         """
         Gets called whenever the user clicks on a layer in the multilayer list
         Makes sure the dock widget updates its data depending on the users selection
         """
+        if self.skip_clicked_event:
+            self.skip_clicked_event = False
+            return
+
         if not isinstance(item, Layer):
             index = self.cbWMS_URL.findText(item.text(0))
             if index != -1 and index != self.cbWMS_URL.currentIndex():
