@@ -6,11 +6,11 @@
 
     Widget to display a WMS (Web Map Service) capabilities document.
 
-    This file is part of mss.
+    This file is part of MSS.
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2022 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2022 by the MSS team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -29,7 +29,7 @@
 import collections
 
 from PyQt5 import QtWidgets
-from mslib.msui.mss_qt import ui_wms_capabilities as ui
+from mslib.utils.qt import ui_wms_capabilities as ui
 
 
 class WMSCapabilitiesBrowser(QtWidgets.QDialog, ui.Ui_WMSCapabilitiesBrowser):
